@@ -1,3 +1,3 @@
-from .__main__ import *
+from .dice import *
 
 __all__ = ["roll_dice", "roll_with_advantage_or_disadvantage", "process_rolls"]
